# eric7.QScintilla.TypingCompleters.__init__

Package implementing typing completers for the various supported programming languages.

### Global Attributes

CompleterRegistry
CompleterRegistryItem

### Classes

None

### Functions

getCompleter | Module function to instantiate a lexer object for a given language.
registerCompleter | Function to register a typing completer for a lexer language.
unregisterTypingCompleter | Function to unregister a previously registered typing completer.

## getCompleter

getCompleter(language, editor, parent=None)

Module function to instantiate a lexer object for a given language.

language (str)
  language of the lexer
editor (QScintilla.Editor)
  reference to the editor object
parent (QObject (optional))
  reference to the parent object (defaults to None)

Return:
  reference to the instantiated typing completer object

Return Type:
  CompleterBase

Up

## registerCompleter

registerCompleter(language, createCompleterFunction, createConfigPageFunction)

Function to register a typing completer for a lexer language.

language (str)
  lexer language of the typing completer
createCompleterFunction (function)
  reference to a function to instantiate a typing completer object
createConfigPageFunction (function)
  reference to a function returning a ready populated configuration widget

Raises KeyError:
  raised when the given name is already in use

Up

## unregisterTypingCompleter

unregisterTypingCompleter(language)

Function to unregister a previously registered typing completer.

language (str)
  lexer language of the typing completer

Up